@@ -59,10 +59,10 @@ def get_enpt_argparser():
     #       => see docs in parsedArgs_to_user_opts() for explanation
     add('-jc', '--json_config', nargs='?', type=str,
         help='file path of a JSON file containing options. See here for an example: '
-             'https://gitext.gfz-potsdam.de/EnMAP/GFZ_Tools_EnMAP_BOX/'
+             'https://git.gfz-potsdam.de/EnMAP/GFZ_Tools_EnMAP_BOX/'
              'EnPT/blob/master/enpt/options/options_default.json')
     add('--CPUs', type=int, default=None,
-        help='number of CPU cores to be used for processing (default: "None" -> use all available')
+        help='number of CPU cores to be used for processing (default: "None" -> use all available)')
     add('-im', '--path_l1b_enmap_image', type=str, default=None,
         help='input path of the EnMAP L1B image to be processed '
              '(zip-archive or root directory; must be given if not contained in --json-config.)')
@@ -108,10 +108,6 @@ def get_enpt_argparser():
     add('--enable_ac', type=_str2bool, default=True, nargs='?', const=True,
         help="Enable atmospheric correction using SICOR algorithm (default: True). If False, the L2A output contains "
              "top-of-atmosphere reflectance")
-    add('--auto_download_ecmwf', type=_str2bool, default=False, nargs='?', const=True,
-        help='Automatically download ECMWF data for atmospheric correction')
-    add('--enable_ice_retrieval', type=_str2bool, default=True, nargs='?', const=True,
-        help='Enable ice retrieval (default); increases accuracy of water vapour retrieval')
     add('--enable_cloud_screening', type=_str2bool, default=False, nargs='?', const=True,
         help='Enable cloud screening during atmospheric correction')
     add('--scale_factor_boa_ref', type=int, default=10000,
