@@ -42,7 +42,8 @@ from pprint import pformat
 
 from jsmin import jsmin
 from cerberus import Validator
-from collections import OrderedDict, Mapping
+from collections import OrderedDict
+from collections.abc import Mapping
 import numpy as np
 from multiprocessing import cpu_count
 
@@ -75,7 +76,6 @@ config_for_testing = dict(
     disable_progress_bars=True,
     is_dummy_dataformat=True,
     enable_ac=False,
-    enable_ice_retrieval=False,
     CPUs=16
 )
 
@@ -119,6 +119,7 @@ config_for_testing_dlr = dict(
 
                      # Arcachon tile 3 ASTER DEM (05/2020)
                      # 'ENMAP01-____L1B-DT000400126_20170218T110119Z_003_V000204_20200508T124425Z__tile3__DEM_ASTER.bsq'
+                     # '15_DEM_UTM__with_prj.tif'
                      )),
     log_level='DEBUG',
     output_dir=os.path.join(path_enptlib,  '..', 'tests', 'data', 'test_outputs'),
@@ -133,7 +134,6 @@ config_for_testing_dlr = dict(
     enable_absolute_coreg=True,
     path_reference_image=os.path.join(path_enptlib, '..', 'tests', 'data', 'T30TXQ_20170218T110111_B05__sub.tif'),
     enable_ac=True,
-    enable_ice_retrieval=False,
     CPUs=32,
     ortho_resampAlg='gauss',
     vswir_overlap_algorithm='swir_only'
@@ -221,12 +221,6 @@ class EnPTConfig(object):
             Enable atmospheric correction using SICOR algorithm (default: True).
             If False, the L2A output contains top-of-atmosphere reflectance.
 
-        :key auto_download_ecmwf:
-            Automatically download ECMWF data for atmospheric correction
-
-        :key enable_ice_retrieval:
-            Enable ice retrieval (default); increases accuracy of water vapour retrieval
-
         :key enable_cloud_screening:
             Enable cloud screening during atmospheric correction
 
@@ -328,8 +322,6 @@ class EnPTConfig(object):
 
         # atmospheric_correction
         self.enable_ac = gp('enable_ac')
-        self.auto_download_ecmwf = gp('auto_download_ecmwf')
-        self.enable_ice_retrieval = gp('enable_ice_retrieval')
         self.enable_cloud_screening = gp('enable_cloud_screening')
         self.scale_factor_boa_ref = gp('scale_factor_boa_ref')
 
